]> git.tuebingen.mpg.de Git - dss.git/blobdiff - snap.h
Fix create mode in case no post-create hook is given.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index 508bbf9312d9f2a343ac2af265799677a372c6a0..5c2f20b2885e19919afabff1369908fdb6c5bf18 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2009 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -26,7 +26,7 @@ enum hook_status {
  * The status of a snapshot.
  *
  * The snapshot directories come in four different flavours, depending
- * on how the two staus flags are set. Examples:
+ * on how the two status flags are set. Examples:
  *
  * Complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43.
  * Complete, being deleted: 1204565370-1204565371.being_deleted.
@@ -48,7 +48,7 @@ struct snapshot {
        int64_t creation_time;
        /**
         * Seconds after the epoch when creation of this snapshot completed.
-        * Only meaningful if the SS_COMPLTE bit is set.
+        * Only meaningful if the SS_COMPLETE bit is set.
         */
        int64_t completion_time;
        /** See \ref snapshot_status_flags. */
@@ -90,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
 
 /**
* Get the oldest snapshot in a snapshot list.
  */
-_static_inline_ struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
+_static_inline_ struct snapshot *get_newest_snapshot(struct snapshot_list *sl)
 {
        if (!sl->num_snapshots)
                return NULL;
-       return sl->snapshots[0];
+       return sl->snapshots[sl->num_snapshots - 1];
 }
@@ -90,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 
 /**
- * Get the oldest snapshot in a snapshot list.
+ * Get the newest snapshot in a snapshot list.
  */